# Computer vision

Following are the computer vision tasks , we are trying to implement in minacv library.


* Whole image classification
* Image Classification With Localization
* Segmentation(pizel wise classification)
    * Semantic segmentation(All the pixels belonging to a particular class are represented by the same color )
    * Instance Segmentation(However, different objects of the same class have different colors)
* Object Detection
* object tracking
* Face recognition
* Image captioning
* Image Describing
* visual_relationship_detection
* Style Transfer
* Image Colorization
* Image Reconstruction
* Image Super-Resolution
* Image Synthesis
* Text to Image(Synthesizing an image based on a textual description.)


